@@ -60,7 +60,7 @@ def GetUserDefinitions(u:User):
 		return defs
 
 
-def CategoryDefinitons(cat:str , limit=10):
+def CategoryDefinitions(cat:str , limit=10):
 	cat = cat.lower()
 	cat_dict = {
 	"college" : "https://www.urbandictionary.com/category.php?category=college",
